summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/sessionset.c
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/sessionset.c')
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/sessionset.c28
1 files changed, 14 insertions, 14 deletions
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/sessionset.c b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/sessionset.c
index 7b5ad921..bea1a7c9 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/sessionset.c
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/third_party/ortp/sessionset.c
@@ -60,27 +60,27 @@ void session_set_destroy(SessionSet *set)
gint session_set_and(SessionSet *sched_set, gint maxs, SessionSet *user_set, SessionSet *result_set)
{
- guint32 *mask1,*mask2,*mask3;
+ guint32 *tqmask1,*tqmask2,*tqmask3;
gint i=0;
gint j,ret=0;
- mask1=(guint32*)&sched_set->rtpset;
- mask2=(guint32*)&user_set->rtpset;
- mask3=(guint32*)&result_set->rtpset;
+ tqmask1=(guint32*)&sched_set->rtpset;
+ tqmask2=(guint32*)&user_set->rtpset;
+ tqmask3=(guint32*)&result_set->rtpset;
while(i<maxs+1){
- *mask3=(*mask1) & (*mask2); /* computes the AND between the two masks*/
+ *tqmask3=(*tqmask1) & (*tqmask2); /* computes the AND between the two tqmasks*/
/* and unset the sessions that have been found from the sched_set */
- *mask1=(*mask1) & (~(*mask3));
- if ((*mask3)!=0){
+ *tqmask1=(*tqmask1) & (~(*tqmask3));
+ if ((*tqmask3)!=0){
for (j=0;j<32;j++){
- if ( ((*mask3)>>j) & 1){
+ if ( ((*tqmask3)>>j) & 1){
ret++;
}
}
}
i+=32;
- mask1++;
- mask2++;
- mask3++;
+ tqmask1++;
+ tqmask2++;
+ tqmask3++;
}
//printf("session_set_and: ret=%i\n",ret);
return ret;
@@ -116,12 +116,12 @@ int session_set_select(SessionSet *recvs, SessionSet *sends, SessionSet *errors)
SessionSet temp;
RtpScheduler *sched=ortp_get_scheduler();
- /*lock the scheduler to not read the masks while they are being modified by the scheduler*/
+ /*lock the scheduler to not read the tqmasks while they are being modified by the scheduler*/
rtp_scheduler_lock(sched);
while(1){
- /* computes the SessionSet intersection (in the other words mask intersection) between
- the mask given by the user and scheduler masks */
+ /* computes the SessionSet intersection (in the other words tqmask intersection) between
+ the tqmask given by the user and scheduler tqmasks */
if (recvs!=NULL){
bits=session_set_and(&sched->r_sessions,sched->all_max,recvs,&temp);
if (bits>0){